@@ -8,4 +8,7 @@ from zope.interface.common.mapping import IFullMapping
 class zodict(odict):
     """Mark ordered dict with corresponding interface.
     """
-    implements(IFullMapping)
\ No newline at end of file
+    implements(IFullMapping)
+    
+    def __init__(self, data=()):
+        odict.__init__(self, data=data)
\ No newline at end of file
